@@ -11,7 +11,7 @@
 
 package Config::Model::TkUI ;
 {
-  $Config::Model::TkUI::VERSION = '1.327';
+  $Config::Model::TkUI::VERSION = '1.328';
 }
 
 use strict;
@@ -231,12 +231,12 @@ sub Populate {
 		     $cw->on_select($item)} ;
     $cw->bind('<Button-3>', $b3_sub) ;
     # pb: rapid click outside the hlist will trigger $b3_sub
-    #$cw->bind('<Double-Button-1>', $b3_sub) ;
+    #$tree->bind('<Double-Button-1>', $b3_sub) ;
 
     # bind button2 to get cut buffer content and try to store cut buffer content
     my $b2_sub = sub{my $item = $tree->nearest($tree->pointery - $tree->rooty) ;
 		     $cw->on_cut_buffer_dump($item)} ;
-    $cw->bind('<Button-2>', $b2_sub) ;
+    $tree->bind('<Button-2>', $b2_sub) ;
 
     $cw->bind('<Control-c>',  sub{ $cw->edit_copy }) ;
     $cw->bind('<Control-v>',  sub{ $cw->edit_paste }) ;
